# CGL Blatt 03

## Bash Pipe
Mit `ls -At1 | tail -n 1` bzw `ls -At1 | head -n 1` kann man sich den Namen der ältesten/neusten Datei/Verzeichnis ausgeben lassen. Mir ist keine Möglichkeit bekannt das nur mit `ls` auf Dateien einzuschränken, mit `find` könnte man sich sowas aber sicher basteln.

## Backup Skript
```bash
#!/usr/bin/env bash

if [ -f "$HOME/backup" ]
then
	echo "Es existiert bereits eine Datei mit dem Namen '$HOME/backup'. Abbruch!"
	exit 1
else
	if [ -d "$HOME/backup" ]
	then
		echo "Es existiert ein Backup-Verzeichnis welches nun genutzt wird"
	else
		echo "Erstelle Backup-Verzeichnis"
		mkdir $HOME/backup
	fi
fi

timestamp=$(date +%Y-%m-%dT%H:%M:%S)

echo "Erstelle Archiv"
tar -czf "$HOME/backup/$timestamp.tar.gz" --exclude="$HOME/backup" --exclude="$HOME/.local" --exclude="$HOME/.cache" "$HOME"
echo "Backup erfolgreich!"
```
(wer mehr output möchte, kann die `-v` Flag bei `tar` enablen, das kann dann aber doch *sehr* verbos werden)

## Bash Syntax
Das Skript muss zu

```bash
#!/bin/bash

for file in $@; do
        content=$(cat "$file")
        echo "File: '$file' content: '$content'"
done
```

geändert, also `$1` durch `$@` ersetzt werden.
Der Grund dafür ist, dass `bash` beim Aufruf des Skripts das Argument `*.txt` bereits expandiert d.h. durch bspw. `foo.txt bar.txt baz.txt` ersetzt.`$1` ist somit der Name einer konkreten Datei.

## Verweise
### Erstellen eines Symlinks
`ln -s hello.txt hello_soft_lnk`
### Erstellen eines Hardlinks
`ln hello.txt hello_hard_lnk`
### Erstellen einer Kopie
`cp hello.txt hello_copy.txt`

### Was passiert beim Ändern des Inhalts von `hello.txt`?
Lässt man sich den Inhalt der Dateien mit `cat` anzeigen so fällt auf, dass der "Inhalt" des Soft- und Hardlinks auch geändert wurde.
Der Inhalt der Kopie jedoch nicht.

### Was passiert beim Löschen der Datei `hello.txt`?
Der Inhalt der Kopie und des Hardlinks kann unverändert angzeigt werden.
Der "Inhalt" des Soft-Links kann nicht mehr angezeigt werden, da die verlinkte Datei nicht gefunden werden kann.


### Unterscheiden von hard und soft link
Der Softlink wird als 
```
lrwxrwxrwx 1 paddi paddi   9 Nov  4 18:06 soft_link -> hello.txt
```
angezeigt - der Hardlink als "normale" Datei.
`file soft_link` bestätigt weiter, dass diese Datei ein `symbolic link to hello.txt` ist, `file hard_link` hingegen ist wie auch die originale Datei `ASCII text`